#!/bin/sh

if [ x"$1" = x"-h" ] || [ x"$1" = x"--help" ] || \
   [ x"$1" = x ] || [ x"$2" = x ] || [ x"$3" != x ]
then
	echo "Usage: $0 CONFIG ARCH" >&2
	exit 1
fi

CONF=$1
if [ ! -f "$CONF" ]
then
	echo "$0: File does not exist: $CONF" >&2
	exit 1
fi

ARCH=$2

eval `grep -E "^(Package|Version):" $CONF | sed "s/: /=/"`
DEB=${Package}_${Version}_${ARCH}.deb

DATA=`awk '/^$/ { tail=1; } { if (tail) print $0; }' $CONF`

# Tempdir

TMP=`mktemp -d`

cleanup() {
	rm -rf $TMP
}

trap cleanup EXIT INT

# Packaging

set -e

echo "2.0" > $TMP/debian-binary

echo "Architecture: $ARCH" > $TMP/control
awk '/^$/ { tail=1; } { if (!tail) print $0; }' $CONF >> $TMP/control
tar cfz $TMP/control.tar.gz -C $TMP control

if [ x"$DATA" = x ]
then
	touch $TMP/data.tar
else
	tar cf $TMP/data.tar $DATA
fi
gzip $TMP/data.tar

rm -f $DEB
ar rc $DEB $TMP/debian-binary $TMP/control.tar.gz $TMP/data.tar.gz
